@@ -23,7 +23,8 @@ def get_Sv(miss,beam=1,ping=1,
 		   pitch_plot=False, 
 		   fix_c = False, 
 		   fix_alpha=False,
-		   fix_sl=False):
+		   fix_sl=False,
+           TVG_cor=True):
 	"""
 	Transform netCDF to Sv and TS with environmental data
 
@@ -225,9 +226,16 @@ def get_Sv(miss,beam=1,ping=1,
 			d0 = d0.values[SNR > 3]
 			d1 = 10*np.log10(d0 - n) 
 			
-			Sv = d1.flatten() - SL - ( 10 *np.log10( c[SNR>3] * tau  / 2  ) ) - PSI + ( 20 * np.log10(d[SNR > 3])) + (2 *alpha[SNR>3] * d[SNR > 3])+G
+			Sv = d1.flatten() - SL - ( 10 *np.log10( c[SNR>3] * tau  / 2  ) ) - PSI - ( 20 * np.log10(d[SNR > 3])) + (2 *alpha[SNR>3] * d[SNR > 3])+G
 			#Sv = d1.flatten() - SL - ( 10 *np.log10( c[SNR>3] * tau  / 2  ) ) - PSI + ( 20 * np.log10(d[SNR > 3])) + (2 *alpha[SNR>3] * d[SNR > 3])+G
 			
+			#a =4
+			         
+			TVG =  - 20 * np.log10(dz) + 2 * alpha[SNR>3] * dz[SNR>3]
+
+			#if TVG_cor == True:
+			#	Sv = Sv - TVG
+			    
 			Sv = pd.DataFrame({'Sv': Sv})
 			Sv['Depth'] = z[SNR>3]
 			Sv['frequency'] = f
@@ -236,6 +244,7 @@ def get_Sv(miss,beam=1,ping=1,
 			Sv['Dive'] = zB1['Dive'][SNR>3]
 			Sv['TS'] = d1.flatten() - SL + ( 40 * np.log10(d[SNR > 3])) + (2 *alpha[SNR>3] * d[SNR > 3])+G
 			Sv['SNR'] = SNR[SNR>3]
+			Sv['TVG'] = TVG
 			Sv['alpha'] = alpha[SNR>3]
 			Sv['c'] = c[SNR>3]
 			Sv['dz'] = dz[SNR>3]
